==> haskell-rsa-2.3.1-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: RSA
version: 2.3.1
id: RSA-2.3.1-1oJupLatlzyHcWBBx2QvTi
key: RSA-2.3.1-1oJupLatlzyHcWBBx2QvTi
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>
author: Adam Wick <awick@galois.com>
stability: stable
synopsis: Implementation of RSA, using the padding schemes of PKCS#1 v2.1.
description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).
category: Cryptography, Codec
abi: 23263c5db9ee3930a1925c66d11a3706
exposed: True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure
import-dirs: /usr/lib/ghc-8.6.5/site-local/RSA-2.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/RSA-2.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/RSA-2.3.1
hs-libraries: HSRSA-2.3.1-1oJupLatlzyHcWBBx2QvTi
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv base-4.12.0.0 binary-0.8.6.0
    bytestring-0.10.8.2 crypto-api-0.13.3-Bqlv92FAlG0F3d21zytrBM
    crypto-pubkey-types-0.4.3-LOlDyw9NiHHe7p3tC6nh2
haddock-interfaces: /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html: /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rsa-2.3.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: RSA
version: 2.3.1
id: RSA-2.3.1-93cTcFOYZjBKu15Fcmf60d
key: RSA-2.3.1-93cTcFOYZjBKu15Fcmf60d
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>
author: Adam Wick <awick@galois.com>
stability: stable
synopsis: Implementation of RSA, using the padding schemes of PKCS#1 v2.1.
description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).
category: Cryptography, Codec
abi: 495c53b86e7644b0729dda26727c3521
exposed: True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure
import-dirs: /usr/lib/ghc-8.6.5/site-local/RSA-2.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/RSA-2.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/RSA-2.3.1
hs-libraries: HSRSA-2.3.1-93cTcFOYZjBKu15Fcmf60d
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv base-4.12.0.0 binary-0.8.6.0
    bytestring-0.10.8.2 crypto-api-0.13.3-Bqlv92FAlG0F3d21zytrBM
    crypto-pubkey-types-0.4.3-BTrEaHpXZcY2Ejyr1YAn3I
haddock-interfaces: /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html: /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
